@@ -54,14 +54,50 @@ def get_docs_agree():
 
 * 2、query：参数被设置在?后面：如"/url?xxx=111&yyy=222"
 
-* 3、body-json: json提交，参数以json的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/json"。注意该模式与body-form不能同时设置。
+* 3、body: json提交，参数以json的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/json"。注意该模式与body-form不能同时设置。
 
-* 4、body-form：表单提交，参数以kv的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/x-www-form-urlencoded"。注意该模式与body-json不能同时设置。
+* 4、body：表单提交，参数以kv的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/x-www-form-urlencoded"。注意该模式与body-json不能同时设置。
 
-* 5、file：上传文件。body设置为form-data，Content-Type设置为"multipart/form-data;boundary=abcefxxx",boundary通常会自动被设置为一个随机字符
+* 5、file：上传文件。body设置为form-data，Content-Type设置为"multipart/form-data;boundary=abcefxxx",boundary分解符通常会自动被设置为一个随机字符
 
 注意：以上345模式，由于值都被设置在body内，所以在同一api内，对于不同的参数，不允许混用不同的模式。唯一的例外是，file模式下（multipart/form-data），既允许同时上传文件，又允许设置其他参数。
 
+**Restful请求示例：**
+~~~python
+### Send POST request with body as form parameters
+POST https://domain.com/post
+Content-Type: application/x-www-form-urlencoded
+
+{
+  "id": 999,
+  "value": "content"
+}
+
+### Send POST request with json body
+POST https://domain.com/post
+Content-Type: application/json
+
+id=999&value=content
+
+### Send a form with the text and file fields
+POST https://domain.com/post
+Content-Type: multipart/form-data; boundary=WebAppBoundary
+
+--WebAppBoundary
+Content-Disposition: form-data; name="element-name"
+Content-Type: text/plain
+
+Name
+--WebAppBoundary
+Content-Disposition: form-data; name="data"; filename="data.json"
+Content-Type: application/json
+
+< ./request-form-data.json
+--WebAppBoundary--
+
+###
+~~~
+
 **参数值类型：在设置schema.yml时，指定type的值允许是以下几种之一**
 
 |类型|说明|
